==> websak-cli-0.2.12.tgz: package/lib/commands/init.js <==
'use strict';

var shell = require('shelljs');
var path = require('path');
var fs = require('fs');
var readlineSync = require('readline-sync');
var util = require('../util');

var DEFAULT_VERSION = '0.0.1';
var DEFAULT_LICENSE = 'MIT';
var DEFAULT_MAIN = 'lib/index.js';

exports.command = 'init';
exports.describe = 'Create pacakage or project';

exports.builder = function (yargs) {
  return yargs.options({
    boilerplate: {
      alias: 'b',
      demand: true,
      describe: 'The boilerplate project',
      default: 'node',
      type: 'string'
    }
  });
};

exports.handler = function (argv) {
  var boilerplate = argv.boilerplate;


  var packageName = void 0;
  while (!(packageName = readlineSync.question('Enter package name:'))) {}
  var packageDir = path.join(process.cwd(), packageName);
  fs.mkdirSync(packageDir);

  var author = void 0;
  while (!(author = readlineSync.question('Enter your name:'))) {}
  var email = readlineSync.questionEMail('Enter your email:');

  var version = DEFAULT_VERSION;
  var license = DEFAULT_LICENSE;
  var main = DEFAULT_MAIN;

  var packageInfo = {
    name: packageName,
    description: packageName,
    version: version,
    homepage: 'https://github.com/' + author + '/' + packageName,
    bugs: 'https://github.com/' + author + '/' + packageName + '/issues',
    repository: {
      type: "git",
      url: 'https://github.com/' + author + '/' + packageName
    },
    main: main,
    author: { name: author, email: email },
    license: license,
    scripts: {
      "lint": "websak lint",
      "clean": "websak clean",
      "prebuild": "npm run lint && npm run clean",
      "build": "websak build",
      "watch": "websak build -w",
      "pretest": "npm run build",
      "test": "websak test",
      "prepublish": "npm test && websak publish -c"
    },
    keywords: packageName.split(/_|-|,|(?=[A-Z])/),
    engines: {
      "node": ">= 4"
    },
    dependencies: {},
    devDependencies: {}
  };

  if (boilerplate === 'node') {
    var pkgPath = path.join(packageDir, 'package.json');
    util.saveJSON(pkgPath, packageInfo);

    fs.mkdirSync(path.join(packageDir, 'src'));
    fs.mkdirSync(path.join(packageDir, 'test'));

    //copy test.js
    var srcTestFilePath = path.resolve(__dirname, '../../resources/default-test.js');
    var destTestFilePath = 'test/' + packageName + '.test.js';
    shell.exec('cp ' + srcTestFilePath + ' ' + destTestFilePath, { cwd: packageDir });

    console.log('Installing websak as dev dependency...');
    shell.exec('npm i websak -D', { silent: true, cwd: packageDir });

    console.log('Creating files...');
    var cmd = ['websak create sublime', 'websak create .gitignore', 'websak create .npmignore', 'websak create readme', 'websak create license', 'websak create .babelrc', 'websak create .eslintrc'].join(' && ');
    shell.exec(cmd, { cwd: packageDir });
  } else {
    return util.error('Currently not support this boilerplate');
  }

  console.log('Init successfully!');
};

==> websak-cli-0.2.13.tgz: package/lib/commands/init.js <==
'use strict';

var shell = require('shelljs');
var path = require('path');
var fs = require('fs');
var readlineSync = require('readline-sync');
var util = require('../util');

var DEFAULT_VERSION = '0.0.1';
var DEFAULT_LICENSE = 'MIT';
var DEFAULT_MAIN = 'lib/index.js';

exports.command = 'init';
exports.describe = 'Create pacakage or project';

exports.builder = function (yargs) {
  return yargs.options({
    boilerplate: {
      alias: 'b',
      demand: true,
      describe: 'The boilerplate project',
      default: 'node',
      type: 'string'
    }
  });
};

exports.handler = function (argv) {
  var boilerplate = argv.boilerplate;


  var packageName = void 0;
  while (!(packageName = readlineSync.question('Enter package name:'))) {}
  var packageDir = path.join(process.cwd(), packageName);
  fs.mkdirSync(packageDir);

  var author = void 0;
  while (!(author = readlineSync.question('Enter your name:'))) {}
  var email = readlineSync.questionEMail('Enter your email:');

  var version = DEFAULT_VERSION;
  var license = DEFAULT_LICENSE;
  var main = DEFAULT_MAIN;

  var packageInfo = {
    name: packageName,
    description: packageName,
    version: version,
    homepage: 'https://github.com/' + author + '/' + packageName,
    bugs: 'https://github.com/' + author + '/' + packageName + '/issues',
    repository: {
      type: "git",
      url: 'https://github.com/' + author + '/' + packageName
    },
    main: main,
    author: { name: author, email: email },
    license: license,
    scripts: {
      "lint": "websak lint",
      "clean": "websak clean -o lib",
      "prebuild": "npm run lint && npm run clean",
      "build": "websak build --src src -o lib",
      "watch": "websak build --src src -o lib -w",
      "pretest": "npm run build",
      "test": "websak test",
      "prepublish": "npm test && websak publish -c"
    },
    keywords: packageName.split(/_|-|,|(?=[A-Z])/),
    engines: {
      "node": ">= 4"
    },
    dependencies: {},
    devDependencies: {}
  };

  if (boilerplate === 'node') {
    var pkgPath = path.join(packageDir, 'package.json');
    util.saveJSON(pkgPath, packageInfo);

    fs.mkdirSync(path.join(packageDir, 'src'));
    fs.mkdirSync(path.join(packageDir, 'test'));

    //copy test.js
    var srcTestFilePath = path.resolve(__dirname, '../../resources/default-test.js');
    var destTestFilePath = 'test/' + packageName + '.test.js';
    shell.exec('cp ' + srcTestFilePath + ' ' + destTestFilePath, { cwd: packageDir });

    console.log('Installing websak as dev dependency...');
    shell.exec('npm i websak -D', { silent: true, cwd: packageDir });

    console.log('Creating files...');
    var cmd = ['websak create sublime', 'websak create .gitignore', 'websak create .npmignore', 'websak create readme', 'websak create license', 'websak create .babelrc', 'websak create .eslintrc'].join(' && ');
    shell.exec(cmd, { cwd: packageDir });
  } else {
    return util.error('Currently not support this boilerplate');
  }

  console.log('Init successfully!');
};
